@@ -85,3 +85,8 @@
 #' @source <https://donnees.montreal.ca/dataset/lieux-culturels>
 "mtl_theatres"
 
+.onLoad <- function(libname, pkgname) {
+  # CRAN OMP THREAD LIMIT
+  Sys.setenv("OMP_THREAD_LIMIT" = 2)
+
+}
\ No newline at end of file
