@@ -864,6 +864,12 @@ nearest_lines <- function(points, lines, snap_dist = 300, max_iter = 10){
 #' @param points A feature collection of points
 #' @param lines A feature collection of linestrings
 #' @param idField The name of the column to use as index for the lines
+#' @param snap_dist A distance (float) given to find for each point its
+#' nearest line in a spatial index. A too big value will produce
+#' unnecessary distance calculations and a too short value will lead to
+#' more iterations to find neighbours. The default value
+#' is Inf. The function will raise an error if some points are too far from
+#' a line.
 #' @param ... unused
 #'
 #' @return A feature collection of points with the projected geometries
@@ -880,7 +886,7 @@ nearest_lines <- function(points, lines, snap_dist = 300, max_iter = 10){
 #'     mtl_network,
 #'     "LineID"
 #' )
-snapPointsToLines2 <- function(points, lines ,idField = NA, ...) {
+snapPointsToLines2 <- function(points, lines ,idField = NA, snap_dist = Inf,  ...) {
 
   #nearest_line_index <- nearest(points,lines)
   if(is.na(idField)){
