@@ -33,13 +33,13 @@ test_that("Testing the isochrone function return the expected result on a simple
   linesdf <- data.frame(wkt = wkt_lines,
                         id = paste("l",1:length(wkt_lines),sep=""))
 
-  all_lines <- st_as_sf(linesdf, wkt = "wkt")
+  all_lines <- st_as_sf(linesdf, wkt = "wkt", crs = 32188)
 
   # definition of one event
   event <- data.frame(x=c(0, 1, 3),
                       y=c(0, 2, 3),
                       id = c(1,2,3))
-  event <- st_as_sf(event, coords = c("x","y"))
+  event <- st_as_sf(event, coords = c("x","y"), crs = 32188)
 
   # calculating the isochrone
   observed <- calc_isochrones(all_lines, 3.5, event[1,],
@@ -116,13 +116,13 @@ test_that("Testing the isochrone function return the expected result on a simple
                         direction = "Both")
   linesdf[2,"direction"] <- "TF"
 
-  all_lines <- st_as_sf(linesdf, wkt = "wkt")
+  all_lines <- st_as_sf(linesdf, wkt = "wkt", crs = 32188)
 
   # definition of one event
   event <- data.frame(x=c(0, 1, 3),
                       y=c(0, 2, 3),
                       id = c(1,2,3))
-  event <- st_as_sf(event, coords = c("x","y"))
+  event <- st_as_sf(event, coords = c("x","y"), crs = 32188)
 
   # calculating the isochrone
   observed <- calc_isochrones(all_lines, 2, event[1,],
@@ -202,13 +202,13 @@ test_that("Testing the isochrone function return the expected result on a simple
   linesdf <- data.frame(wkt = wkt_lines,
                         id = paste("l",1:length(wkt_lines),sep=""))
 
-  all_lines <- st_as_sf(linesdf, wkt = "wkt")
+  all_lines <- st_as_sf(linesdf, wkt = "wkt", crs = 32188)
 
   # definition of one event
   event <- data.frame(x=c(0, 1, 3),
                       y=c(0, 2, 3),
                       id = c(1,2,3))
-  event <- st_as_sf(event, coords = c("x","y"))
+  event <- st_as_sf(event, coords = c("x","y"), crs = 32188)
 
   # calculating the isochrone
   observed <- calc_isochrones(all_lines, dists = c(1.5,2.5), event[1,],
@@ -221,9 +221,9 @@ test_that("Testing the isochrone function return the expected result on a simple
   exp_len2 <- 5
   exp_nb2 <- 10
 
-  obs_len1 <- sum(st_length(subset(observed, observed$distance == 1.5)))
+  obs_len1 <- as.numeric(sum(st_length(subset(observed, observed$distance == 1.5))))
   obs_nb1 <- nrow(subset(observed, observed$distance == 1.5))
-  obs_len2 <- sum(st_length(subset(observed, observed$distance == 2.5)))
+  obs_len2 <- as.numeric(sum(st_length(subset(observed, observed$distance == 2.5))))
   obs_nb2 <- nrow(subset(observed, observed$distance == 2.5))
 
   v1 <- c(exp_len1, exp_nb1, exp_len2, exp_nb2)
@@ -233,3 +233,61 @@ test_that("Testing the isochrone function return the expected result on a simple
 
   expect_false(test)
 })
+
+
+
+
+test_that("Testing that we can specify dists as a list of dists", {
+
+  #definition of a simple situation
+  wkt_lines <- c(
+    "LINESTRING (0 0, 1 0)",
+    "LINESTRING (1 0, 2 0)",
+    "LINESTRING (2 0, 3 0)",
+    "LINESTRING (0 1, 1 1)",
+    "LINESTRING (1 1, 2 1)",
+    "LINESTRING (2 1, 3 1)",
+    "LINESTRING (0 2, 1 2)",
+    "LINESTRING (1 2, 2 2)",
+    "LINESTRING (2 2, 3 2)",
+    "LINESTRING (0 3, 1 3)",
+    "LINESTRING (1 3, 2 3)",
+    "LINESTRING (2 3, 3 3)",
+    "LINESTRING (0 0, 0 1)",
+    "LINESTRING (0 1, 0 2)",
+    "LINESTRING (0 2, 0 3)",
+    "LINESTRING (1 0, 1 1)",
+    "LINESTRING (1 1, 1 2)",
+    "LINESTRING (1 2, 1 3)",
+    "LINESTRING (2 0, 2 1)",
+    "LINESTRING (2 1, 2 2)",
+    "LINESTRING (2 2, 2 3)",
+    "LINESTRING (3 0, 3 1)",
+    "LINESTRING (3 1, 3 2)",
+    "LINESTRING (3 2, 3 3)"
+  )
+
+  linesdf <- data.frame(wkt = wkt_lines,
+                        id = paste("l",1:length(wkt_lines),sep=""))
+
+  all_lines <- st_as_sf(linesdf, wkt = "wkt", crs = 32188)
+
+  # definition of one event
+  event <- data.frame(x=c(0, 1, 3),
+                      y=c(0, 2, 3),
+                      id = c(1,2,3))
+  event <- st_as_sf(event, coords = c("x","y"), crs = 32188)
+
+  # calculating the isochrone
+  observed <- calc_isochrones(all_lines, event,
+                              dists = list(c(1.5,2.5),
+                                           c(1.5,2),
+                                           c(1)
+                                           ),
+                              donught = TRUE,
+                              mindist = 1)
+
+
+  expect_false(FALSE)
+})
+
